#include "portability.h"
#include "decoder.h"
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include "plugin.h"



void mpgfio_defaults_decoder_plugin(plugin_fcn_dsc *f)
{
    f[0].name            = "mpgdecoder_alloc";
    f[1].name            = "mpgdecoder_free";
    f[2].name            = "mpgdecoder_init";
    f[3].name            = "mpgdecoder_open";
    f[4].name            = "mpgdecoder_close";
    f[5].name            = "mpgdecoder_play_frame";
    f[6].name            = "mpgdecoder_version_06";

    f[0].func.alloc      = default_mpgdecoder_alloc;
    f[1].func.free       = default_mpgdecoder_free;
    f[2].func.init       = default_mpgdecoder_init;
    f[3].func.open       = default_mpgdecoder_open;
    f[4].func.close      = default_mpgdecoder_close;
    f[5].func.play       = default_mpgdecoder_play_frame;
    f[6].func.version    = default_mpgdecoder_version_06;
}

/*
 * This value must be 2 greater than the last index offset above.
 * +1 because it is zero based above, but this is a a size,
 * and +1 for the NULL entry at the end of the list
 */
#define MPGDECODER_NUM_FPS  8


#if defined(WIN32)
  
char *mpgfio_dlerror(void)
{
    void *msg;

    FormatMessage( 
        FORMAT_MESSAGE_ALLOCATE_BUFFER | 
        FORMAT_MESSAGE_FROM_SYSTEM | 
        FORMAT_MESSAGE_IGNORE_INSERTS,
        NULL,
        GetLastError(),
        0,
        (LPTSTR) &msg,
        0,
        NULL 
    );
    return (char *) msg;
}

void *mpgfio_dlopen(const char *filename)
{
    return LoadLibrary(filename);
}


void *mpgfio_dlsym(void *handle, char *symbol)
{
    return GetProcAddress(handle, symbol);
}

#else

char *mpgfio_dlerror(void)
{
    char *errmsg = dlerror();

    if (!errmsg) {
        errmsg = strdup("dlerror: unknown error");
    }
    return errmsg;
}

void *mpgfio_dlopen(const char *filename)
{
    return dlopen(filename, RTLD_LAZY);
}


void *mpgfio_dlsym(void *handle, char *symbol)
{
    return dlsym(handle, symbol);
}


#endif


plugin_fcn_dsc *mpgfio_alloc_decoder_plugin(void)
{
    plugin_fcn_dsc *f;

    f = (plugin_fcn_dsc *) calloc(MPGDECODER_NUM_FPS, sizeof(plugin_fcn_dsc));
    if (!f) {
        return f;
    }
    mpgfio_defaults_decoder_plugin(f);
    return f;
}


/*
 * Portability issue here.  This is UNIX (SYSV style) dynamic library
 * load.  This must be re-written to call LoadLibraryEx() and
 * GetProcAddress() on Windows.  Some UNIX systems (HP-UX) have a 
 * different API for dynamically loading shared libraries; shl_load()
 * and shl_findsym() must be used.
 */
char *mpegfio_load_decoder_plugin(char *file, plugin_fcn_dsc *fp_mpgdecoder)
{
    void *ctx;
    char *libname = NULL;
    int sts = 1;
    char *nameptr;
    int i;
    void (*tmpfp)(void);
    char *errmsg = NULL;

    /*
     * Build a shared library name string.  Allocate enough space where
     * a relative path prefix and a shared library extension can be added.
     * .dll is the worst case length for all systems; this is only .dll
     * for Windows, .so for most UNIX and .sl for HP-UX.
     */
    libname = (char *) malloc(sizeof("./") + strlen(file) + sizeof(".dll"));
    if (!libname) {
        goto clean_exit;
    }

    /*
     * Always build library path with relative extension.  This is not
     * always used.  Use nameptr to point at the start of the name passed in. 
     */
    strcpy(libname, "./");
    strcat(libname, file);
    nameptr = libname+2;
    if (!strrchr(nameptr, '.')) {
#if defined(__hpux)
        strcat(libname, ".sl");
#else
#  if !defined(WIN32)
        strcat(libname, ".so");
#  else
        strcat(libname, ".dll");
#endif
#endif
    }

    ctx = mpgfio_dlopen(nameptr);
    if (!ctx) {
        if (nameptr[0] != '/') {
            ctx = mpgfio_dlopen(libname);
        }
    }
    if (!ctx) {
        errmsg = strdup(mpgfio_dlerror());
        goto clean_exit;
    }


    for (i=0; fp_mpgdecoder[i].name; i++) {
        tmpfp = mpgfio_dlsym(ctx, fp_mpgdecoder[i].name);
        if (!tmpfp) {
            errmsg = strdup(mpgfio_dlerror());
            goto clean_exit;
        }
        fp_mpgdecoder[i].func.voidcast = tmpfp;
    }

    sts = 0;
clean_exit:
    if (libname) {
        free(libname);
    }
    if (sts) {
        mpgfio_defaults_decoder_plugin(fp_mpgdecoder);
    }
    return errmsg;
}
